<?php
/**
 * Copyright (с) Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2022 All Rights Reserved
 *
 * Licensed under CLOUD LINUX LICENSE AGREEMENT
 * https://www.cloudlinux.com/legal/
 */

namespace CloudLinux\SmartAdvice\App\Service;

/**
 * Mail advices
 */
class MailerAdvices extends Mailer {
	/**
	 * Number of new advices.
	 *
	 * @var int
	 */
	private $count;

	/**
	 * Constructor.
	 *
	 * @param array $payload data.
	 */
	public function __construct( $payload ) {
		$this->count = array_key_exists( 'count', $payload ) ? (int) $payload['count'] : 0;
	}

	/**
	 * Can send to WP users.
	 *
	 * @return bool
	 */
	public function availableToWpUsers() {
		return $this->count > 0;
	}

	/**
	 * Can send to Panel users.
	 *
	 * @return bool
	 */
	public function availableToPanelUsers() {
		return $this->count > 0;
	}

	/**
	 * Subject.
	 *
	 * @param string $site_url url.
	 *
	 * @return string
	 */
	public function subject( $site_url ) {
		$subject = 'New performance Advice';
		if ( ! empty( $site_url ) ) {
			$subject .= ' for ' . $site_url;
		}

		return $subject;
	}

	/**
	 * Template file.
	 *
	 * @return string
	 */
	public function template() {
		return 'letter.advices';
	}

	/**
	 * Template data.
	 *
	 * @return array
	 */
	public function payload() {
		return array(
			'number_of_advices' => $this->count,
		);
	}
}
